##
##  bird.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         bird
Summary:      BIRD Internet Routing Daemon
URL:          http://bird.network.cz/
Vendor:       L. Forst, M. Mare, P. Machek, O. Filip
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Routing
License:      GPL
Version:      2.13.1
Release:      20230623

#   list of sources
Source0:      ftp://bird.network.cz/pub/bird/bird-%{version}.tar.gz
Source1:      rc.bird
Patch0:       bird.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, flex, bison, m4
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  readline
PreReq:       readline

%description
    BIRD is an IPv4/IPv6 capable Internet routing daemon supporting
    Border Gateway Protocol (BGPv4), Routing Information Protocol
    (RIPv2), Open Shortest Path First protocol (OSPFv2), static routes,
    inter-table protocol, etc.

%track
    prog bird = {
        version   = %{version}
        url       = ftp://bird.network.cz/pub/bird/
        regex     = bird-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure package
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/bird \
        --localstatedir=%{l_prefix}/var/bird \
        --with-protocols=all

    #   build package
    %{l_make} %{l_mflags}

%install
    #   install package
    %{l_make} %{l_mflags} install \
        prefix=$RPM_BUILD_ROOT%{l_prefix} \
        exec_prefix=$RPM_BUILD_ROOT%{l_prefix} \
        sysconfdir=$RPM_BUILD_ROOT%{l_prefix}/etc/bird \
        localstatedir=$RPM_BUILD_ROOT%{l_prefix}/var/bird

    #   strip down package
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.bird} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   adjust default configuration
    %{l_shtool} subst \
        -e 's;#log "tmp" all;log "%{l_prefix}/var/bird/bird.log" all;' \
        $RPM_BUILD_ROOT%{l_prefix}/etc/bird/bird.conf

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/bird/*'

%files -f files

%clean

